.. -*- mode: rst ; ispell-local-dictionary: "american" -*-


git flow |BRANCH| checkout - Check out a |BRANCH| branch
====================================================================


Synopsis
-----------

.. parsed-literal::

  `git flow` |`BRANCH`| `checkout` nameprefix


Description
-----------

If exactly one |BRANCH| branch starts with ``nameprefix``, check out
(switch to) that branch.


Options
-----------

  -h, --help          Show help message and exit.
